Index: trunk/MagicSoft/Mars/macros/bootcampstandardanalysis.C
===================================================================
--- trunk/MagicSoft/Mars/macros/bootcampstandardanalysis.C	(revision 3234)
+++ trunk/MagicSoft/Mars/macros/bootcampstandardanalysis.C	(revision 3255)
@@ -114,11 +114,23 @@
     //
 
-    MCalibrationCam         calcam;
+    MCalibrationChargeCam   calcam;
     MExtractedSignalCam     sigcam;
+    MCalibrationChargePINDiode pindiode;
     
+    //
+    // As long, as we don't have digital modules, 
+    // we have to set the color of the pulser LED by hand
+    //
+    calcam.SetColor(MCalibrationChargeCam::kECT1);
+    pindiode.SetColor(MCalibrationChargePINDiode::kECT1);
+
     plist2.AddToList(&geomcam);
     plist2.AddToList(&pedcam);
     plist2.AddToList(&calcam);
     plist2.AddToList(&sigcam);
+    plist2.AddToList(&pindiode);
+
+   // hists
+    MFillH fillpin("MHCalibrationChargePINDiode", "MExtractedSignalPINDiode");
 
     //tasks
@@ -126,15 +138,8 @@
     read2.DisableAutoScheme();
 
-    MExtractPINDiode      pincalc;
-    MExtractBlindPixel    blindcalc;
-    MExtractSignal        sigsig;
-    MCalibrationCalc      calcalc;
-
-    MFillH fillpin("MHCalibrationChargePINDiode", "MExtractedSignalPINDiode");
-    //
-    // As long, as we don't have digital modules, 
-    // we have to set the color of the pulser LED by hand
-    //
-    calcalc.SetPulserColor(MCalibrationCalc::kECT1);
+    MExtractPINDiode       pincalc;
+    MExtractBlindPixel     blindcalc;
+    MExtractSignal         sigsig;
+    MCalibrationChargeCalc calcalc;
 
     // 
@@ -156,6 +161,6 @@
     tlist2.AddToList(&cont);
     //
+    tlist2.AddToList(&fillpin);
     tlist2.AddToList(&calcalc);
-    tlist2.AddToList(&fillpin);
     //
     // Create and setup the eventloop
Index: trunk/MagicSoft/Mars/macros/calibration.C
===================================================================
--- trunk/MagicSoft/Mars/macros/calibration.C	(revision 3234)
+++ trunk/MagicSoft/Mars/macros/calibration.C	(revision 3255)
@@ -23,9 +23,12 @@
 \* ======================================================================== */
 
+const TString pedfile = "../20040215_16770_P_OffCrab4_E.root";
+const TString calfile = "../20040215_16771_C_OffCrab4_E.root";
+
 //const TString pedfile = "/mnt/users/mdoro/Mars/Data/20040201_14418_P_OffMrk421-1_E.root";
 //const TString calfile = "/mnt/users/mdoro/Mars/Data/20040201_1441*_C_OffMrk421-1_E.root";
 
-const TString pedfile = "/mnt/Data/rootdata/CrabNebula/2004_02_10/20040210_14607_P_CrabNebula_E.root";
-const TString calfile = "/mnt/Data/rootdata/CrabNebula/2004_02_10/20040210_14608_C_CrabNebula_E.root";
+//const TString pedfile = "/mnt/Data/rootdata/CrabNebula/2004_02_10/20040210_14607_P_CrabNebula_E.root";
+//const TString calfile = "/mnt/Data/rootdata/CrabNebula/2004_02_10/20040210_14608_C_CrabNebula_E.root";
 
 //const TString pedfile = "/mnt/Data/rootdata/CrabNebula/2004_01_26/20040125_10412_P_Crab-On_E.root";
@@ -43,5 +46,5 @@
 
     MStatusDisplay *display = new MStatusDisplay;
-    display->SetUpdateTime(3000);
+    display->SetUpdateTime(500);
     display->Resize(850,700);
 
@@ -110,5 +113,5 @@
     // Look at one specific pixel, after all the histogram manipulations:
     //
-    hpedcam[9].DrawClone("fourier");
+    hpedcam[9].DrawClone("fourierevents");
 
 
@@ -218,5 +221,5 @@
 
     MExtractedSignalCam     sigcam;
-    MCalibrationCam         calcam;
+    MCalibrationChargeCam   calcam;
     MHCalibrationRelTimeCam timecam;
     //
@@ -244,9 +247,9 @@
     // thus take the sliding window
     //		
-    MExtractPINDiode     pincalc;
-    MExtractBlindPixel   blindcalc;
-    MExtractSignal2      sigcalc2;
-    MArrivalTimeCalc2    timecalc;
-    MCalibrationCalc     calcalc;
+    MExtractPINDiode       pincalc;
+    MExtractBlindPixel     blindcalc;
+    MExtractSignal2        sigcalc2;
+    MArrivalTimeCalc2      timecalc;
+    MCalibrationChargeCalc calcalc;
 
     MFillH filltime("MHCalibrationRelTimeCam", "MArrivalTime");
@@ -274,5 +277,5 @@
     // we have to set the color of the pulser LED by hand
     //
-    calcalc.SetPulserColor(MCalibrationCalc::kECT1);
+//    calcalc.SetPulserColor(MCalibrationCalc::kECT1);
 
     //
@@ -338,11 +341,10 @@
     // print the most important results of all pixels
     //
-    //    calcam.Print();
+    calcam.Print();
 
     //
     // just one example how to get the plots of individual pixels
     //
-    //  calcam[563].DrawClone();
-    //  calcam[564].DrawClone();
+    calcam[564].DrawClone();
 
     // Create histograms to display
@@ -559,5 +561,4 @@
     CamDraw(c9,disp21,calcam,2,2,2);
 
-
     // Rel. Times
     TCanvas &c10 = display->AddTab("Fitted Rel. Times");
@@ -581,5 +582,4 @@
     CamDraw(c12,disp27,calcam,1,2,2);
     CamDraw(c12,disp28,calcam,2,2,2);
-
 }
 
@@ -603,7 +603,7 @@
       TH1D *obj2 = (TH1D*)obj1->Projection();
       
+      obj2->Sumw2();
       obj2->Draw();
       obj2->SetBit(kCanDelete);
-      
 
       const Double_t min   = obj2->GetBinCenter(obj2->GetXaxis()->GetFirst());
Index: trunk/MagicSoft/Mars/macros/pedphotcalc.C
===================================================================
--- trunk/MagicSoft/Mars/macros/pedphotcalc.C	(revision 3234)
+++ trunk/MagicSoft/Mars/macros/pedphotcalc.C	(revision 3255)
@@ -34,8 +34,8 @@
 #include "MGeomCamMagic.h"
 #include "MEvtLoop.h"
-#include "MCalibrationCam.h"
+#include "MCalibrationChargeCam.h"
 #include "MExtractedSignalCam.h"
 #include "MExtractSignal.h" 
-#include "MCalibrationCalc.h"
+#include "MCalibrationChargeCalc.h"
 #include "MCerPhotEvt.h"
 #include "MCalibrate.h"
@@ -109,6 +109,6 @@
   
   // containers  
-  MCalibrationCam     calcam;
-  MExtractedSignalCam sigcam;
+  MCalibrationChargeCam calcam;
+  MExtractedSignalCam   sigcam;
   
   plist2.AddToList(&geomcam);
@@ -121,23 +121,17 @@
   read2.DisableAutoScheme();
   
-  MExtractPINDiode     pincalc;
-  MExtractBlindPixel   blindcalc;
-  MExtractSignal       sigcalc;
-  MCalibrationCalc     calcalc;
+  MExtractPINDiode       pincalc;
+  MExtractBlindPixel     blindcalc;
+  MExtractSignal         sigcalc;
+  MCalibrationChargeCalc calcalc;
   
   MFillH fillpin("MHCalibrationChargePINDiode", "MExtractedSignalPINDiode");
   // 
   // Apply a filter against cosmics
   // (was directly in MCalibrationCalc in earlier versions)
   //
   MFCosmics            cosmics;
   MContinue            cont(&cosmics);
 
-  //
-  // As long as we don't have digital modules, 
-  // we have to set the color of the pulser LED by hand
-  //
-  calcalc.SetPulserColor(MCalibrationCalc::kECT1);
-  
   tlist2.AddToList(&read2);
   tlist2.AddToList(&geomapl);
@@ -151,6 +145,6 @@
   tlist2.AddToList(&cont);
   //
+  tlist2.AddToList(&fillpin);
   tlist2.AddToList(&calcalc);
-  tlist2.AddToList(&fillpin);
   
   // Execute second loop (calibration)
@@ -121,23 +121,17 @@
   // 
   // Apply a filter against cosmics
-  // (was directly in MCalibrationCalc in earlier versions)
+  // (was directly in MCalibrationChargeCalc in earlier versions)
   //
   MFCosmics            cosmics;
